@@ -1,4 +1,5 @@
 use {
+    crate::units::Units,
     argh::FromArgs,
     std::path::PathBuf,
 };
@@ -6,8 +7,6 @@ use {
 #[derive(FromArgs)]
 /// List your filesystems.
 ///
-/// All units are SI.
-///
 /// Source and doc at https://github.com/Canop/lfs
 pub struct Args {
     /// print the version
@@ -26,6 +25,10 @@ pub struct Args {
     #[argh(switch, short = 'j')]
     pub json: bool,
 
+    #[argh(option, default = "Default::default()")]
+    /// units: 'SI' (default) or 'binary'
+    pub units: Units,
+
     #[argh(positional)]
     /// if a path is provided, only the device holding this path will be shown
     pub path: Option<PathBuf>,
@@ -51,3 +54,13 @@ impl argh::FromArgValue for BoolArg {
         }
     }
 }
+
+impl argh::FromArgValue for Units {
+    fn from_arg_value(value: &str) -> Result<Self, String> {
+        match value.to_lowercase().as_ref() {
+            "si" => Ok(Self::Si),
+            "binary" => Ok(Self::Binary),
+            _ => Err(format!("Illegal value: {:?} - valid values are 'SI' and 'binary'", value)),
+        }
+    }
+}
